@@ -4,7 +4,7 @@ use strict;
 use Carp;
 use base qw(Unicode::Collate);
 
-our $VERSION = '0.83';
+our $VERSION = '0.84';
 
 use File::Spec;
 
@@ -12,14 +12,15 @@ use File::Spec;
 my $PL_EXT  = '.pl';
 
 my %LocaleFile = map { ($_, $_) } qw(
-   af ar as az be bg ca cs cy da eo es et fi fil fo fr gu
-   ha haw hi hr hu hy ig is ja kk kl kn ko kok ln lt lv
+   af ar as az be bg ca cs cy da eo es et fa fi fil fo fr
+   gu ha haw hi hr hu hy ig is ja kk kl kn ko kok ln lt lv
    mk ml mr mt nb nn nso om or pa pl ro ru se si sk sl sq
-   sr sv ta te th tn to tr uk vi wae wo yo zh
+   sr sv ta te th tn to tr uk ur vi wae wo yo zh
 );
    $LocaleFile{'default'} = '';
 # aliases
-   $LocaleFile{'bs'} = 'hr';
+   $LocaleFile{'bs'}      = 'hr';
+   $LocaleFile{'sr_Latn'} = 'hr';
 # short file names
    $LocaleFile{'de__phonebook'}   = 'de_phone';
    $LocaleFile{'es__traditional'} = 'es_trad';
@@ -50,8 +51,17 @@ sub _locale {
 				  "_$TypeAlias{$1}" : "_$1"/e;
 	$LocaleFile{$locale} and return $locale;
 
-	my ($l,$t,$v) = split(/_/, $locale.'__');
-	for my $loc ("${l}_${t}_$v", "${l}_$t", "${l}__$v", "${l}__$t", $l) {
+	my @code = split /_/, $locale;
+	my $lan = shift @code;
+	my $scr = @code && length $code[0] == 4 ? ucfirst shift @code : '';
+	my $reg = @code && length $code[0] <  4 ? uc      shift @code : '';
+	my $var = @code                         ?         shift @code : '';
+
+	for my $loc (
+	    "${lan}_${scr}_${reg}_$var", "${lan}_${scr}_$var",
+	    "${lan}_${reg}_$var",        "${lan}__$var",
+	    "${lan}_${scr}_${reg}",      "${lan}_${scr}",
+	    "${lan}_${reg}",		   $lan) {
 	    $LocaleFile{$loc} and return $loc;
 	}
     }
@@ -102,10 +112,10 @@ locale		based CLDR
 af		2.0 = 1.8.1
 ar		2.0
 as		2.0 = 1.8.1
-az		2.0 = 1.8.1
+az		2.0 = 1.8.1 (type="standard")
 be		2.0
 bg		2.0
-bs		2.0
+bs		2.0 (alias source="hr")
 ca		2.0 = 1.8.1 (alt="proposed" type="standard")
 cs		2.0 = 1.8.1 (type="standard")
 cy		2.0 = 1.8.1
@@ -115,6 +125,7 @@ eo		2.0 = 1.8.1
 es		2.0 (type="standard")
 es__traditional 2.0 = 1.8.1 (type="traditional")
 et		2.0 = 1.8.1
+fa		2.0 = 1.8.1
 fi		2.0 = 1.8.1 (type="standard" alt="proposed")
 fi__phonebook	2.0 = 1.8.1 (type="phonebook")
 fil		2.0 (type="standard") = 1.8.1
@@ -123,15 +134,15 @@ fr		2.0 (fr_CA, backwards="on")
 gu		2.0 (type="standard")
 ha		2.0
 haw		2.0 = 1.8.1
-hi		2.0
-hr		2.0
+hi		2.0 (type="standard")
+hr		2.0 (type="standard")
 hu		2.0 = 1.8.1 (alt="proposed" type="standard")
 hy		2.0 = 1.8.1
 ig		2.0 = 1.8.1
-is		2.0 = 1.8.1
+is		2.0 = 1.8.1 (type="standard")
 ja		2.0 = 1.8.1 (type="standard")
 kk		2.0
-kl		2.0 = 1.8.1
+kl		2.0 = 1.8.1 (type="standard")
 kn		2.0 (type="standard")
 ko		2.0 = 1.8.1 (type="standard")
 kok		2.0 = 1.8.1
@@ -151,22 +162,24 @@ pa		2.0 = 1.8.1
 pl		2.0 = 1.8.1
 ro		2.0 (type="standard")
 ru		2.0
-se		2.0 (type="standard") = 1.8.1
+se		2.0 = 1.8.1 (type="standard")
 si		2.0 (type="standard")
 si__dictionary	2.0 (type="dictionary")
 sk		2.0 (type="standard")
 sl		2.0 = 1.8.1 (type="standard" alt="proposed")
 sq		2.0 = 1.8.1 (alt="proposed" type="standard")
 sr		2.0 (type="standard")
+sr_Latn		2.0 = 1.8.1 (alias source="hr")
 sv		2.0 (type="standard")
 sv__reformed	2.0 = 1.8.1 (type="reformed")
 ta		2.0
 te		2.0
 th		2.0 (type="standard")
 tn		2.0 = 1.8.1
-to		2.0 = 1.8.1
+to		2.0 = 1.8.1 (type="standard" alt="proposed")
 tr		2.0 = 1.8.1 (type="standard")
 uk		2.0
+ur		2.0
 vi		2.0 = 1.8.1
 wae		2.0
 wo		1.8.1
@@ -215,21 +228,23 @@ The C<new> method returns a collator object.
 
 A parameter list for the constructor is a hash, which can include
 a special key C<locale> and its value (case-insensitive) standing
-for a two-letter language code (ISO-639) like C<'en'> for English.
+for a Unicode base language code (two or three-letter).
 For example, C<Unicode::Collate::Locale-E<gt>new(locale =E<gt> 'FR')>
 returns a collator tailored for French.
 
-C<$locale_name> may be suffixed with a territory(country)
-code or a variant code, which are separated with C<'_'>.
+C<$locale_name> may be suffixed with a Unicode script code (four-letter),
+a Unicode region code, a Unicode language variant code. These codes are
+case-insensitive, and separated with C<'_'> or C<'-'>.
 E.g. C<en_US> for English in USA,
-C<es_ES_traditional> for Spanish in Spain (Traditional),
+C<az_Cyrl> for Azerbaijani in Cyrillic script,
+C<es_ES_traditional> for Spanish in Spain (Traditional).
 
 If C<$localename> is not defined,
 fallback is selected in the following order:
 
-    1. language_territory_variant
-    2. language_territory
-    3. language__variant
+    1. language with a variant code
+    2. language with a script code
+    3. language with a region code
     4. language
     5. default
 
@@ -283,7 +298,7 @@ this method returns a string C<'default'> meaning no special tailoring.
 =head2 A list of tailorable locales
 
       locale name       description
-    ----------------------------------------------------------
+    --------------------------------------------------------------
       af                Afrikaans
       ar                Arabic
       as                Assamese
@@ -300,6 +315,7 @@ this method returns a string C<'default'> meaning no special tailoring.
       es                Spanish
       es__traditional   Spanish ('ch' and 'll' as a grapheme)
       et                Estonian
+      fa                Persian
       fi                Finnish (v and w are primary equal)
       fi__phonebook     Finnish (v and w as separate characters)
       fil               Filipino
@@ -343,6 +359,7 @@ this method returns a string C<'default'> meaning no special tailoring.
       sl                Slovenian
       sq                Albanian
       sr                Serbian
+      sr_Latn           Serbian in Latin (tailored as Croatian)
       sv                Swedish (v and w are primary equal)
       sv__reformed      Swedish (v and w as separate characters)
       ta                Tamil
@@ -352,6 +369,7 @@ this method returns a string C<'default'> meaning no special tailoring.
       to                Tonga
       tr                Turkish
       uk                Ukrainian
+      ur                Urdu
       vi                Vietnamese
       wae               Walser
       wo                Wolof
@@ -361,7 +379,7 @@ this method returns a string C<'default'> meaning no special tailoring.
       zh__gb2312han     Chinese (ideographs: GB-2312 order)
       zh__pinyin        Chinese (ideographs: pinyin order)
       zh__stroke        Chinese (ideographs: stroke order)
-    ----------------------------------------------------------
+    --------------------------------------------------------------
 
 Locales according to the default UCA rules include
 chr (Cherokee),
